<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://helpshelf.co
 * @since             1.0.0
 * @package           Helpshelf
 *
 * @wordpress-plugin
 * Plugin Name:       Helpshelf
 * Plugin URI:        https://help.helpshelf.co/article/59io3ip2pa-word-press-plugin
 * Description:       Plugin to integrate the HelpShelf widget on your WordPress site to give your customers easy access to your content through AI-powered search.
 * Version:           1.0.0
 * Author:            Helpshelf
 * Author URI:        https://helpshelf.co/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       helpshelf
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'HELPSHELF_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-helpshelf-activator.php
 */
function activate_helpshelf() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-helpshelf-activator.php';
	Helpshelf_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-helpshelf-deactivator.php
 */
function deactivate_helpshelf() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-helpshelf-deactivator.php';
	Helpshelf_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_helpshelf' );
register_deactivation_hook( __FILE__, 'deactivate_helpshelf' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-helpshelf.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_helpshelf() {

	$plugin = new Helpshelf();
	$plugin->run();

}
run_helpshelf();

//----------------


global $site_id;



// Hook to add the script to the <head> tag
add_action('wp_head', 'helpshelf_add_script_to_head');


function get_site_key() {
    $site_id = wp_cache_get('site_key');

    if (false === $site_id) {
        global $wpdb;
        $site_id = $wpdb->get_var($wpdb->prepare("SELECT option_value FROM {$wpdb->prefix}helpshelfconfig WHERE option_name = %s", 'SITE_KEY'));

        wp_cache_set('site_key', $site_id, 60 * 60 * 24); // Cache for 1 day
    }

    return $site_id;
}

function helpshelf_add_script_to_head() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'helpshelfconfig';

    // Retrieve the SITE_KEY from the database using a prepared statement
    $site_id = get_site_key();
    // var_dump($site_id);
    // exit();
    if ($site_id) {
        echo '<script type="text/javascript" id="hs-loader">
            (function() {
                var po = document.createElement("script"); po.type = "text/javascript"; po.async = true;
                po.src = "https://s3.amazonaws.com/helpshelf-production/gen/loader/' . esc_js($site_id) . '.min.js";
                po.onload = po.onreadystatechange = function() {
                    var rs = this.readyState; if (rs && rs != "complete" && rs != "loaded") return;
                    HelpShelfLoader = new HelpShelfLoaderClass(); HelpShelfLoader.identifyFromURL("' . esc_js($site_id) . '");
                };
                var s = document.getElementsByTagName("script")[0]; s.parentNode.insertBefore(po, s);
            })();
        </script>';
    } else {
        echo "<!-- HelpShelf SITE_KEY not found -->";
    }
}

// Hook to create the config table on plugin activation
register_activation_hook(__FILE__, 'helpshelf_create_config_table');

function helpshelf_create_config_table() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'helpshelfconfig';

    $charset_collate = $wpdb->get_charset_collate();

    $sql = "CREATE TABLE $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        option_name varchar(55) NOT NULL,
        option_value varchar(255) NOT NULL,
        PRIMARY KEY  (id)
    ) $charset_collate;";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
}

// Add settings page under the "Settings" menu
add_action('admin_menu', 'helpshelf_plugin_menu');

function helpshelf_plugin_menu() {
    add_options_page(
        'HelpShelf Settings',
        'HelpShelf',
        'manage_options',
        'helpshelf-plugin',
        'helpshelf_plugin_options_page'
    );
}

// Register settings and fields
add_action('admin_init', 'helpshelf_plugin_settings');

function helpshelf_plugin_settings() {
    register_setting('helpshelf_plugin_options', 'helpshelf_site_id');

    add_settings_section(
        'helpshelf_plugin_main_section',
        'Main Settings',
        null,
        'helpshelf-plugin'
    );

    add_settings_field(
        'helpshelf_site_id',
        'SITE_KEY',
        'helpshelf_site_id_callback',
        'helpshelf-plugin',
        'helpshelf_plugin_main_section'
    );
}

// Display settings page
function helpshelf_plugin_options_page($site_id) {

        // Check if the form is submitted
    if (isset($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['helpshelf_site_id'])) {
        // Verify nonce before processing form data
        if ( ! isset( $_POST['helpshelf_nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['helpshelf_nonce'] ) ), 'helpshelf_save_site_id_action' ) ) {
            die( 'Security check failed' );
        }

        // Sanitize the input and save the SITE_KEY
        helpshelf_save_site_id(null, sanitize_text_field( wp_unslash( $_POST['helpshelf_site_id'] ) ));
    }

    // Retrieve the SITE_KEY from the database
    global $wpdb;
    $table_name = $wpdb->prefix . 'helpshelfconfig';
    $site_id = get_site_key();
    ?>
    <div class="wrap">
        <h1>HelpShelf Settings</h1>
        <form method="post" action="">
            <?php wp_nonce_field('helpshelf_save_site_id_action', 'helpshelf_nonce'); ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Site Key</th>
                    <td>
                        <input type="text" id="helpshelf_site_id" name="helpshelf_site_id" value="<?php echo esc_attr($site_id); ?>" />
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

function helpshelf_save_site_id($old_value, $new_value) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'helpshelfconfig';

    // Check if SITE_KEY already exists (cached)
    $exists = wp_cache_get('helpshelf_site_key_exists');

    if (false === $exists) {
        $exists = $wpdb->prepare("SELECT COUNT(*) FROM {$wpdb->prefix}helpshelfconfig WHERE option_name = %s", 'SITE_KEY');

        wp_cache_set('helpshelf_site_key_exists', $exists, 60 * 60 * 24); // Cache for 1 day
    }

    if ($exists) {
        // Update existing value using a prepared statement
        $wpdb->update(
            $table_name,
            array('option_value' => $new_value),
            array('option_name' => 'SITE_KEY'),
            array('%s'),
            array('%s')
        );

        // Delete the cached value
        wp_cache_delete('helpshelf_site_key');
    } else {
        // Insert new value using a prepared statement
        $wpdb->insert(
            $table_name,
            array('option_name' => 'SITE_KEY', 'option_value' => $new_value),
            array('%s', '%s')
        );
    }
}